@@ -14,6 +14,9 @@ class SmartqqClient:
         return lambda message: ((orig_handler(message, self.env) if self.passing_env else orig_handler(message)),
                                 self.stopped)[1]
 
+    def raw_handler_wrapper(self, orig_handler):
+        return lambda info: (orig_handler(info), self.stopped)[1]
+
     @staticmethod
     def get_group_name(group_info):
         return group_info["name"]
@@ -83,7 +86,9 @@ class SmartqqClient:
                  db_identify_string=None):
         self.session = requests.Session()
         self.login_pipeline = SmartqqLoginPipeline(
-            self.session, barcode_handler, exception_handler=login_exception_handler
+            self.session,
+            self.raw_handler_wrapper(barcode_handler) if barcode_handler is not None else barcode_handler,
+            exception_handler=login_exception_handler
         )
         self.friend_message_handler = (
             self.handler_wrapper(friend_message_handler) if friend_message_handler is not None
@@ -112,13 +117,13 @@ class SmartqqClient:
     def run(self):
         if self.login_data is None:
             self.login()
+        if self.stopped:
+            return None
         contact_db = pymongo.MongoClient()["python-smartqq-client"]
         self.contact_manager = ContactDatabaseManager(contact_db, self.login_data, self.session,
                                                       identify_string=self.db_identify_string)
-        # self.contact_manager.get_data()
         self.group_manager = GroupDatabaseManager(contact_db, self.login_data, self.session,
                                                   identify_string=self.db_identify_string)
-        # self.group_manager.get_data()
         self.env["contact_manager"] = self.contact_manager
         self.env["group_manager"] = self.group_manager
         if self.login_done_handler is not None:
