@@ -1,4 +1,5 @@
 from .MessageHandler import MessageHandler
+from .MessageErrcodeException import MessageErrcodeException
 
 
 class SmartqqMessageHandler(MessageHandler):
@@ -27,7 +28,17 @@ class SmartqqMessageHandler(MessageHandler):
 
     @staticmethod
     def print_all_handler(friend_message_handler=None, group_message_handler=None):
-        result = SmartqqMessageHandler(lambda x: x.json()["result"][0])
+
+        def message_preprocess(data):
+            message = data.json()
+            if "errcode" in message:
+                print(message)
+                raise MessageErrcodeException
+            if "result" not in message:
+                print(message)
+                raise MessageErrcodeException
+            return message["result"][0]
+        result = SmartqqMessageHandler(message_preprocess)
         result.add_handler(SmartqqMessageHandler.friend_message_filter,
                            friend_message_handler if friend_message_handler is not None
                            else SmartqqMessageHandler.friend_message_print_handler)
